You are viewing a plain text version of this content. The canonical link for it is here.
Posted to issues@ozone.apache.org by GitBox <gi...@apache.org> on 2021/09/20 14:39:53 UTC

[GitHub] [ozone] sodonnel commented on pull request #2662: HDDS-5766. Speed up some OM tests by skipping SCM safemode check

sodonnel commented on pull request #2662:
URL: https://github.com/apache/ozone/pull/2662#issuecomment-922990358


   Updated tests ran in:
   
   ```
   [INFO] Tests run: 9, Failures: 0, Errors: 0, Skipped: 0, Time elapsed: 65.194 s - in org.apache.hadoop.ozone.om.TestOzoneManagerConfiguration
   
   Warning:  Tests run: 10, Failures: 0, Errors: 0, Skipped: 2, Time elapsed: 72.674 s - in org.apache.hadoop.ozone.om.TestOzoneManagerHAMetadataOnly
   
   [INFO] Tests run: 6, Failures: 0, Errors: 0, Skipped: 0, Time elapsed: 21.88 s - in org.apache.hadoop.ozone.om.TestOzoneManagerListVolumes
   
   [INFO] Tests run: 5, Failures: 0, Errors: 0, Skipped: 0, Time elapsed: 46.888 s - in org.apache.hadoop.ozone.om.TestOmMetrics
   ```
   
   Saving 208 + 291 + 134 + 29 = 662 seconds saved (~ 11 minutes).


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: issues-unsubscribe@ozone.apache.org

For queries about this service, please contact Infrastructure at:
users@infra.apache.org



---------------------------------------------------------------------
To unsubscribe, e-mail: issues-unsubscribe@ozone.apache.org
For additional commands, e-mail: issues-help@ozone.apache.org